Documentation
¶
Index ¶
Constants ¶
const ( // FileTargetType is a file target FileTargetType = TargetType("File") // JournalTargetType is a journalctl target JournalTargetType = TargetType("Journal") // DroppedTargetType is a target that's been dropped. DroppedTargetType = TargetType("dropped") )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Target ¶
type Target interface {
// Type of the target
Type() TargetType
// DiscoveredLabels returns labels discovered before any relabeling.
DiscoveredLabels() model.LabelSet
// Labels returns labels that are added to this target and its stream.
Labels() model.LabelSet
// Ready tells if the targets is ready
Ready() bool
// Details is additional information about this target specific to its type
Details() interface{}
}
Target is a promtail scrape target
Click to show internal directories.
Click to hide internal directories.